==> kdevelop-5.2.3.tar.xz: kdevelop-5.2.3/kdevplatform/vcs/interfaces/ipatchsource.cpp <==
/*
   Copyright 2006 David Nolden <david.nolden.kdevelop@art-master.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "ipatchsource.h"

#include <QIcon>

using namespace KDevelop;


QIcon IPatchSource::icon() const
{
    return QIcon();
}

IPatchReview::~IPatchReview()
{

}

void IPatchSource::cancelReview()
{

}

bool IPatchSource::finishReview(QList< QUrl > selection)
{
    Q_UNUSED(selection);
    return true;
}

bool IPatchSource::canCancel() const
{
    return false;
}

QMap<QUrl, KDevelop::VcsStatusInfo::State> IPatchSource::additionalSelectableFiles() const
{
    return QMap<QUrl, KDevelop::VcsStatusInfo::State>();
}

bool IPatchSource::canSelectFiles() const
{
    return false;
}

QString IPatchSource::finishReviewCustomText() const
{
    return QString();
}

QWidget* IPatchSource::customWidget() const
{
    return nullptr;
}

uint IPatchSource::depth() const
{
    return 0;
}

==> kdevelop-5.4.2.tar.xz: kdevelop-5.4.2/kdevplatform/vcs/interfaces/ipatchsource.cpp <==
/*
   Copyright 2006 David Nolden <david.nolden.kdevelop@art-master.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "ipatchsource.h"

#include <QIcon>

using namespace KDevelop;


QIcon IPatchSource::icon() const
{
    return QIcon();
}

IPatchReview::~IPatchReview()
{

}

void IPatchSource::cancelReview()
{

}

bool IPatchSource::finishReview(const QList<QUrl>& selection)
{
    Q_UNUSED(selection);
    return true;
}

bool IPatchSource::canCancel() const
{
    return false;
}

QMap<QUrl, KDevelop::VcsStatusInfo::State> IPatchSource::additionalSelectableFiles() const
{
    return QMap<QUrl, KDevelop::VcsStatusInfo::State>();
}

bool IPatchSource::canSelectFiles() const
{
    return false;
}

QString IPatchSource::finishReviewCustomText() const
{
    return QString();
}

QWidget* IPatchSource::customWidget() const
{
    return nullptr;
}

uint IPatchSource::depth() const
{
    return 0;
}
